@@ -8,7 +8,7 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:MAROS';
-our $VERSION = '1.34';
+our $VERSION = '1.35';
 
 use MooseX::App::Meta::Role::Attribute::Option;
 use MooseX::App::Exporter qw(app_usage app_description app_base app_fuzzy app_strict app_prefer_commandline app_permute option parameter);
@@ -39,6 +39,7 @@ sub import {
 sub init_meta {
     my ($class,%args) = @_;
     
+    # Get required roles and metaroles
     $args{roles}        = ['MooseX::App::Role::Base'];
     $args{metaroles}    = {
         class               => [
@@ -81,6 +82,7 @@ sub new_with_command {
     my $meta        = $class->meta;
     my $metameta    = $meta->meta;
     
+    # Sanity check
     Moose->throw_error('new_with_command may only be called from the application base package:'.$class)
         if $metameta->does_role('MooseX::App::Meta::Role::Class::Command')
         || ! $metameta->does_role('MooseX::App::Meta::Role::Class::Base');
@@ -97,7 +99,14 @@ sub new_with_command {
     }
     
     # Get ARGV
-    my $parsed_argv = MooseX::App::ParsedArgv->instance();
+    my $argv = delete $args{ARGV};
+    my $parsed_argv;
+    if (defined $argv) {
+        $parsed_argv = MooseX::App::ParsedArgv->new( argv => $argv );
+    } else {
+        $parsed_argv = MooseX::App::ParsedArgv->instance();
+    }
+    
     my $first_argv  = $parsed_argv->first_argv;
     
     # Requested help
@@ -239,14 +248,15 @@ command line applications without having to worry about most of the annoying
 things usually involved. Just take any existing L<Moose> class, add a single 
 line (C<use MooseX-App qw(PluginA PluginB ...);>) and create one class
 for each command in an underlying namespace. Options and positional parameters
-can be defined as simple L<Moose> accessors.
+can be defined as simple L<Moose> accessors using the C<option> and
+C<parameter> keywords repectively.
 
 MooseX-App will then
 
 =over
 
-=item * Find, load and initialise the command classes (see L<MooseX::App::Simple>
-for single command applications)
+=item * Find, load and initialise the command classes (see 
+L<MooseX::App::Simple> for single class/command applications)
 
 =item * Create automated help and documentation from modules POD as well as
 attributes metadata and type constraints
@@ -304,19 +314,20 @@ Furthermore, all options and parameters can also be supplied via %ENV
   option 'some_option' => (
       is            => 'rw',
       isa           => 'Str',
-      cmd_env       => 'SOME_OPTION',
+      cmd_env       => 'SOME_OPTION', # sets the env key
   );
 
-Moose type constraints help MooseX::App to construct meaningful error messages
-and parse @ARGV in a meaningful way. These type constraints are supported
+Moose type constraints help MooseX::App to construct helpful error messages
+and parse @ARGV in a meaningful way. The following type constraints are 
+supported:
 
 =over
 
-=item * ArrayRef: Specify multiple values ('--list value1 --list value2',
-also see L<app_permute>)
+=item * ArrayRef: Specify multiple values ('--opt value1 --opt value2',
+also see L<app_permute> and L<cmd_split>)
 
-=item * HashRef: Specify multiple key value pairs (--option key=value, 
-also see L<app_permute>)
+=item * HashRef: Specify multiple key value pairs ('--opt key=value --opt
+key2=value2', also see L<app_permute>)
 
 =item * Enum: Display all possibilites
 
@@ -336,13 +347,19 @@ MooseX::App command line application.
  my $myapp_command = MyApp->new_with_command();
 
 This constructor reads the command line arguments and tries to create a 
-command class instance. If it fails it retuns a 
+command class instance. If it fails it returns a 
 L<MooseX::App::Message::Envelope> object holding an error message.
 
 You can pass a hash of default/fallback params to new_with_command
 
  my $obj = MyApp->new_with_command(%default);
 
+Optionally you can pass a custom ARGV to this constructor
+
+ my $obj = MyApp->new_with_command( ARGV => \@myARGV );
+
+However, if you do so you must take care of propper @ARGV encoding yourself.
+
 =head2 initialize_command_class
 
  my $obj = MyApp->initialize_command_class($command_name,%default);
@@ -351,6 +368,8 @@ Helper method to instantiate the command class for the given command.
 
 =head1 GLOBAL OPTIONS
 
+These options may be used to alter the default behaviour of MooseX-App.
+
 =head2 app_base
 
  app_base 'my_script'; # Defaults to $0
@@ -361,33 +380,33 @@ be changed via the app_base function.
 
 =head2 app_fuzzy
 
- app_fuzzy(1); # default
+ app_fuzzy 1; # default
  OR
- app_fuzzy(0);
+ app_fuzzy 0;
 
 Enables fuzzy matching of commands and attributes. Is turned on by default.
 
 =head2 app_strict
 
- app_strict(0); # default 
+ app_strict 0; # default 
  OR
- app_strict(1); 
+ app_strict 1; 
 
 If strict is enabled the program will terminate with an error message if
 superfluous/unknown positional parameters are supplied. If disabled all 
-extra parameters will be copied to the L<extra_argv> attribute. 
+extra parameters will be copied to the L<extra_argv> attribute.
 
 The command_strict config in the command classes allows one to set this option
 individually for each command in the respective command class.
 
 =head2 app_prefer_commandline
 
- app_prefer_commandline(0); # default
+ app_prefer_commandline 0; # default
  or
- app_prefer_commandline(1);
+ app_prefer_commandline 1;
 
 Specifies if parameters/options supplied via @ARGV,%ENV should take precedence
-over arguments passed to new_with_command.
+over arguments passed directly to new_with_command.
 
 =head2 app_namespace
 
@@ -399,19 +418,20 @@ Usually MooseX::App will take the package name of the base class as the
 namespace for commands. This namespace can be changed and you can add
 multiple extra namespaces.
 
-If app_namespace is called with no parameters then autoloading of command
+If app_namespace is called with no arguments then autoloading of command
 classes will be disabled entirely.
 
 =head2 app_command_name
 
  app_command_name {
-     my ($package) = shift;
+     my ($package_short,$package_full) = @_;
      # munge package name;
      return $command_name;
  };
 
 This coderef can be used to control how autoloaded package names should be 
-translated to command names.
+translated to command names. If this command returns nothing the respective
+command class will be skipped and not loaded.
 
 =head2 app_command_register
 
@@ -420,35 +440,34 @@ translated to command names.
     undo    => 'MyApp::Commands::UndoSomething';
 
 This keyword can be used to register additional commands. Especially
-useful in conjunction with app_namespace.
+useful in conjunction with app_namespace and disabled autoloading.
 
 =head2 app_description
 
  app_description qq[Description text];
 
-Set the description. If not set this information will be taken from the
-Pod DESCRIPTION or OVERVIEW sections. (see command_description to set usage 
-per command)
+Set the app description text. If not set this information will be taken from 
+the Pod DESCRIPTION or OVERVIEW sections. (see command_description to set 
+usage per command)
 
 =head2 app_usage
 
  app_usage qq[myapp --option ...];
 
-Set custom usage. If not set this will be taken from the Pod SYNOPSIS or 
-USAGE section. If both sections are not available, the usage
-information will be autogenerated. (see command_usage to set usage per 
-command)
+Set a custom usage text. If not set this will be taken from the Pod SYNOPSIS 
+or USAGE section. If both sections are not available, the usage information 
+will be autogenerated. (see command_usage to set usage per command)
 
 =head2 app_permute
 
- app_permute(0); # default
+ app_permute 0; # default
  OR
- app_permute(1);
+ app_permute 1;
 
-Allows to specify multiple values with one key. So instead of writing
+Allows one to specify multiple values with one key. So instead of writing
 C<--list element1 --list element2 --list element3> one might write
 C<--list element1 element2 element3> for ArrayRef elements. HashRef elements
-may be expressed as <--hash key=value key2=value2>
+may be expressed as <--hash key=value key2=value2>.
 
 =head1 GLOBAL ATTRIBUTES
 
@@ -473,19 +492,19 @@ Options and parameters accept extra attributes for customisation:
 
 =item * cmd_flag - Override option/parameter name
 
-=item * cmd_aliases - Additional option/parameter  names
+=item * cmd_aliases - Additional option/parameter name aliases
 
-=item * cmd_split - Split values into ArrayRefs
+=item * cmd_split - Split values into ArrayRefs on this token
 
 =item * cmd_position - Specify option/parameter order in help
 
 =item * cmd_env - Read options/parameters from %ENV
 
-=item * cmd_count - Value of option equals to number of occurences in @ARGV
+=item * cmd_count - Value of option equals to number of occurrences in @ARGV
 
 =back
 
-Refer to L<MooseX::App::Meta::Role::Attribute::Option> for detailed 
+Refer to L<MooseX::App::Meta::Role::Attribute::Option> for detailed
 documentation.
 
 =head1 METADATA
@@ -528,8 +547,8 @@ Currently the following plugins are shipped with MooseX::App
 
 =item * L<MooseX::App::Plugin::BashCompletion>
 
-Adds a command that genereates a bash completion script for your application.
-See L<MooseX::App::Plugin::ZshCompletion> for Z shell .
+Adds a command that generates a bash completion script for your application.
+See third party L<MooseX::App::Plugin::ZshCompletion> for Z shell completion.
 
 =item * L<MooseX::App::Plugin::Color>
 
@@ -546,7 +565,7 @@ Try to find config files in users home directory.
 =item * L<MooseX::App::Plugin::Term>
 
 Prompt user for options and parameters that were not provided via options or 
-params. Prompt offers basic editing capabilities and history.
+params. Prompt offers basic editing capabilities and non-persistent history.
 
 =item * L<MooseX::App::Plugin::Typo>
 
@@ -562,11 +581,11 @@ Display full manpage of application and commands.
 
 =item * L<MooseX::App::Plugin::MutexGroup>
 
-Allow for mutally exclusive options
+Allow for mutally exclusive options.
 
 =item * L<MooseX::App::Plugin::Depends>
 
-Adds dependent options
+Adds dependent options.
 
 =back
 
@@ -588,8 +607,8 @@ to include the following line in your base class
 
 When manually registering command classes (eg. via app_command_register) in
 multiple base classes with different sets of plugins (why would you ever want 
-to do that?), then meta attributes may miss some attribute metaclasses. In 
-this case you need to load the missing attribute traits explicitely:
+to do that?), then meta attributes may lack some attribute metaclasses. In 
+this case you need to load the missing attribute traits explicitly:
 
  option 'argument' => (
     depends => 'otherargument',
@@ -631,9 +650,13 @@ Michael G, Thomas Klausner, Yanick Champoux, Edward Baudrez, David Golden,
 J.R. Mash, Thilo Fester, Gregor Herrmann, Sergey Romanov, Sawyer X, Roman F.,
 Hunter McMillen, Maik Hentsche, Alexander Stoddard
 
+You are more than welcome to contribute to MooseX-App. Please have a look
+at the L<https://github.com/maros/MooseX-App/issues?q=is%3Aissue+is%3Aopen+label%3AWishlist>
+list of open wishlist issues for ideas.
+
 =head1 COPYRIGHT
 
-MooseX::App is Copyright (c) 2012-15 Maroš Kollár.
+MooseX::App is Copyright (c) 2012-16 Maroš Kollár.
 
 This library is free software and may be distributed under the same terms as 
 perl itself. The full text of the licence can be found in the LICENCE file 
