@@ -31,7 +31,6 @@ has 'argv' => (
         if ($@) {
             @argv = @ARGV;
         }
-        
         return \@argv;
     },
 );
@@ -58,10 +57,21 @@ has 'elements' => (
 
 sub BUILD {
     my ($self) = @_;
+    
+    # Register singleton
     $SINGLETON = $self;
     return $self;
 }
 
+sub DEMOLISH {
+    my ($self) = @_;
+    
+    # Unregister singleton if it is stll the same
+    $SINGLETON = undef
+        if defined $SINGLETON
+        && $SINGLETON == $self;
+}
+
 sub instance {
     my ($class) = @_;
     unless (defined $SINGLETON) {
@@ -106,7 +116,7 @@ sub _build_elements {
                             );
                             push(@elements,$options{$flag});
                         } else {
-                            $options{$flag}->inc_occurence;
+                            $options{$flag}->inc_occurrence;
                         }
                         $lastkey = $options{$flag};
                     }
@@ -123,7 +133,7 @@ sub _build_elements {
                         );
                         push(@elements,$options{$key});
                     } else {
-                        $options{$key}->inc_occurence;
+                        $options{$key}->inc_occurrence;
                     }
                     $options{$key}->add_value($value);
                 }
@@ -138,7 +148,7 @@ sub _build_elements {
                         );
                         push(@elements,$options{$key});
                     } else {
-                        $options{$key}->inc_occurence;
+                        $options{$key}->inc_occurrence;
                     }
                     $lastkey = $options{$key};
                 }
