@@ -7,7 +7,7 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:MAROS';
-our $VERSION = 1.32;
+our $VERSION = 1.35;
 
 use Moose::Exporter;
 use MooseX::App::Exporter qw(app_usage app_description app_base app_fuzzy app_strict app_prefer_commandline app_permute option parameter command_short_description command_long_description command_usage command_strict);
@@ -38,7 +38,7 @@ sub import {
 sub init_meta {
     my ($class,%args) = @_;
     
-    my $for_class       = $args{for_class};
+    # Get required roles and metaroles
     $args{roles}        = ['MooseX::App::Role::Base' ];
     $args{metaroles}    = {
         class               => [
@@ -52,14 +52,16 @@ sub init_meta {
     };
     my $meta = MooseX::App::Exporter->process_init_meta(%args);
     
-    $for_class->meta->app_commands({ 'self' => $for_class });
+    # Register only one command
+    $meta->app_commands({ 'self' => $args{for_class} });
     
     return $meta;
 }
 
 sub new_with_options {
     my ($class,@args) = @_;
-
+    
+    # Sanity check
     Moose->throw_error('new_with_options is a class method')
         if ! defined $class || blessed($class);
 
@@ -73,8 +75,15 @@ sub new_with_options {
         Moose->throw_error('new_with_command got invalid extra arguments');
     }
     
-    my $parsed_argv = MooseX::App::ParsedArgv->instance();
-        
+    # Get ARGV
+    my $argv = delete $args{ARGV};
+    my $parsed_argv;
+    if (defined $argv) {
+        $parsed_argv = MooseX::App::ParsedArgv->new( argv => $argv );
+    } else {
+        $parsed_argv = MooseX::App::ParsedArgv->instance();
+    }
+    
     return $class->initialize_command_class($class,%args);
 }
 
@@ -124,7 +133,7 @@ And then in some simple wrapper script:
 
 =head1 DESCRIPTION
 
-MooseX-App::Simple works basically just as MooseX::App, however it does 
+MooseX-App-Simple works basically just as MooseX::App, however it does 
 not search for commands and assumes that you have all options and parameters 
 defined in the current class.
 
@@ -138,13 +147,19 @@ MooseX::App command line application.
  my $myapp_command = MyApp->new_with_options();
 
 This method reads the command line arguments from the user and tries to create
-instantiate the current class with the ARGV-input. If it fails it retuns a 
+instantiate the current class with the ARGV-input. If it fails it returns a 
 L<MooseX::App::Message::Envelope> object holding an error message.
 
 You can pass a hash or hashref of default params to new_with_options
 
  MyApp->new_with_options( %default );
 
+Optionally you can pass a custom ARGV to this constructor
+
+ my $obj = MyApp->new_with_options( ARGV => \@myARGV );
+
+However, if you do so you must take care of propper @ARGV encoding yourself.
+
 =head1 OPTIONS
 
 Same as in L<MooseX::App>
